"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai = require("chai");
var chaiAsPromised = require("chai-as-promised");
var message_1 = require("./message");
var path = require("path");
var expect = chai.expect;
chai.use(chaiAsPromised);
describe("Message Spec", function () {
    var currentDir = (process && process.mainModule) ? path.dirname(process.mainModule.filename) : "";
    var validJSON = "{ \"description\": \"a test mesage\", \"content\": { \"name\": \"Mary\" } }";
    context("when not given any message content", function () {
        it("should throw an Error", function () {
            expect(function () { return message_1.default({
                consumer: "a-consumer",
                dir: currentDir
            }); }).to.throw(Error);
        });
    });
    context("when not given a consumer", function () {
        it("should throw an Error", function () {
            expect(function () { return message_1.default({
                provider: "a-provider",
                dir: currentDir,
                content: validJSON
            }); }).to.throw(Error);
        });
    });
    context("when not given a provider", function () {
        it("should throw an Error", function () {
            expect(function () { return message_1.default({
                consumer: "a-provider",
                dir: currentDir,
                content: validJSON
            }); }).to.throw(Error);
        });
    });
    context("when not given a pact dir", function () {
        it("should throw an Error", function () {
            expect(function () { return message_1.default({
                consumer: "a-consumer",
                content: validJSON
            }); }).to.throw(Error);
        });
    });
    context("when given an invalid JSON document", function () {
        it("should throw an Error", function () {
            expect(function () { return message_1.default({
                consumer: "some-consumer",
                provider: "a-provider",
                dir: currentDir,
                content: "{ \"unparseable\" }"
            }); }).to.throw(Error);
        });
    });
    context("when given the correct arguments", function () {
        it("should return a message object", function () {
            var message = message_1.default({
                consumer: "some-consumer",
                provider: "a-provider",
                dir: currentDir,
                content: validJSON
            });
            expect(message).to.be.a("object");
            expect(message).to.respondTo("createMessage");
        });
    });
});
//# sourceMappingURL=message.spec.js.map